You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hc.apache.org by ol...@apache.org on 2018/08/14 18:50:42 UTC

[3/4] httpcomponents-core git commit: - Always use blocks - Add missing serial version ID (default 1L) - Camel-case names. - Don't nest in else clause unnecessarily. - Remove declared exceptions that are not thrown (but don't break BC.)

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncRequestConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncRequestConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncRequestConsumer.java
index 4057b11..cc765fd 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncRequestConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncRequestConsumer.java
@@ -90,11 +90,11 @@ public abstract class AbstractAsyncRequestConsumer<T> implements HttpAsyncReques
      * to find out whether or not the message content has been fully consumed.
      *
      * @param decoder content decoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
     protected abstract void onContentReceived(
-            ContentDecoder decoder, IOControl ioctrl) throws IOException;
+            ContentDecoder decoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to generate a result object from the received HTTP request
@@ -141,8 +141,8 @@ public abstract class AbstractAsyncRequestConsumer<T> implements HttpAsyncReques
      */
     @Override
     public final void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
-        onContentReceived(decoder, ioctrl);
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
+        onContentReceived(decoder, ioControl);
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncResponseConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncResponseConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncResponseConsumer.java
index 0459fd2..da7deed 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncResponseConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/AbstractAsyncResponseConsumer.java
@@ -78,11 +78,11 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
      * to find out whether or not the message content has been fully consumed.
      *
      * @param decoder content decoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
     protected abstract void onContentReceived(
-            ContentDecoder decoder, IOControl ioctrl) throws IOException;
+            ContentDecoder decoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked if the response message encloses a content entity.
@@ -143,8 +143,8 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
      */
     @Override
     public final void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
-        onContentReceived(decoder, ioctrl);
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
+        onContentReceived(decoder, ioControl);
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncClientExchangeHandler.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestConsumer.java
index 9524169..fb60724 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestConsumer.java
@@ -82,7 +82,7 @@ public class BasicAsyncRequestConsumer extends AbstractAsyncRequestConsumer<Http
 
     @Override
     protected void onContentReceived(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         Asserts.notNull(this.buf, "Content buffer");
         this.buf.consumeContent(decoder);
     }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestProducer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestProducer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestProducer.java
index 2c7a5aa..72575ec 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestProducer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestProducer.java
@@ -120,9 +120,9 @@ public class BasicAsyncRequestProducer implements HttpAsyncRequestProducer {
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         if (this.producer != null) {
-            this.producer.produceContent(encoder, ioctrl);
+            this.producer.produceContent(encoder, ioControl);
             if (encoder.isCompleted()) {
                 this.producer.close();
             }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseConsumer.java
index 66fd4e3..60b13bf 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseConsumer.java
@@ -80,7 +80,7 @@ public class BasicAsyncResponseConsumer extends AbstractAsyncResponseConsumer<Ht
 
     @Override
     protected void onContentReceived(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         Asserts.notNull(this.buf, "Content buffer");
         this.buf.consumeContent(decoder);
     }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseProducer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseProducer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseProducer.java
index 8e83c89..6450340 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseProducer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncResponseProducer.java
@@ -104,9 +104,9 @@ public class BasicAsyncResponseProducer implements HttpAsyncResponseProducer {
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         if (this.producer != null) {
-            this.producer.produceContent(encoder, ioctrl);
+            this.producer.produceContent(encoder, ioControl);
             if (encoder.isCompleted()) {
                 this.producer.close();
             }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/ErrorResponseProducer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/ErrorResponseProducer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/ErrorResponseProducer.java
index 6a2df67..d9a9209 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/ErrorResponseProducer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/ErrorResponseProducer.java
@@ -78,8 +78,8 @@ public class ErrorResponseProducer implements HttpAsyncResponseProducer {
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
-        this.contentProducer.produceContent(encoder, ioctrl);
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
+        this.contentProducer.produceContent(encoder, ioControl);
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncClientExchangeHandler.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncClientExchangeHandler.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncClientExchangeHandler.java
index d66f356..71f0c74 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncClientExchangeHandler.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncClientExchangeHandler.java
@@ -84,10 +84,10 @@ public interface HttpAsyncClientExchangeHandler extends Closeable, Cancellable {
      * to resume output event notifications when more content is made available.
      *
      * @param encoder content encoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void produceContent(ContentEncoder encoder, IOControl ioctrl) throws IOException;
+    void produceContent(ContentEncoder encoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the request has been fully written out.
@@ -121,10 +121,10 @@ public interface HttpAsyncClientExchangeHandler extends Closeable, Cancellable {
      * processing more content.
      *
      * @param decoder content decoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void consumeContent(ContentDecoder decoder, IOControl ioctrl) throws IOException;
+    void consumeContent(ContentDecoder decoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the response has been fully processed.

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestConsumer.java
index 2739b62..f23848e 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestConsumer.java
@@ -73,10 +73,10 @@ public interface HttpAsyncRequestConsumer<T> extends Closeable {
      * processing more content.
      *
      * @param decoder content decoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void consumeContent(ContentDecoder decoder, IOControl ioctrl) throws IOException;
+    void consumeContent(ContentDecoder decoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the request has been fully processed.

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestProducer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestProducer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestProducer.java
index 3d320ba..3b49f4f 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestProducer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncRequestProducer.java
@@ -85,10 +85,10 @@ public interface HttpAsyncRequestProducer extends Closeable {
      * to resume output event notifications when more content is made available.
      *
      * @param encoder content encoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void produceContent(ContentEncoder encoder, IOControl ioctrl) throws IOException;
+    void produceContent(ContentEncoder encoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the request has been fully written out.

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseConsumer.java
index 257bff5..cb165bb 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseConsumer.java
@@ -73,10 +73,10 @@ public interface HttpAsyncResponseConsumer<T> extends Closeable, Cancellable {
      * processing more content.
      *
      * @param decoder content decoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void consumeContent(ContentDecoder decoder, IOControl ioctrl) throws IOException;
+    void consumeContent(ContentDecoder decoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the response has been fully processed.

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseProducer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseProducer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseProducer.java
index e66e76a..dcedfc6 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseProducer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncResponseProducer.java
@@ -66,10 +66,10 @@ public interface HttpAsyncResponseProducer extends Closeable {
      * to resume output event notifications when more content is made available.
      *
      * @param encoder content encoder.
-     * @param ioctrl I/O control of the underlying connection.
+     * @param ioControl I/O control of the underlying connection.
      * @throws IOException in case of an I/O error
      */
-    void produceContent(ContentEncoder encoder, IOControl ioctrl) throws IOException;
+    void produceContent(ContentEncoder encoder, IOControl ioControl) throws IOException;
 
     /**
      * Invoked to signal that the response has been fully written out.

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncService.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncService.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncService.java
index a7cb2a6..c7ddba1 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncService.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/HttpAsyncService.java
@@ -312,9 +312,8 @@ public class HttpAsyncService implements NHttpServerEventHandler {
                 closeHandlers(state);
                 if (ex instanceof RuntimeException) {
                     throw (RuntimeException) ex;
-                } else {
-                    log(ex);
                 }
+                log(ex);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/NullRequestConsumer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/NullRequestConsumer.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/NullRequestConsumer.java
index 4ade458..00b1b22 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/NullRequestConsumer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/NullRequestConsumer.java
@@ -51,7 +51,7 @@ class NullRequestConsumer implements HttpAsyncRequestConsumer<Object> {
 
     @Override
     public void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         int lastRead;
         do {
             this.buffer.clear();

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/PipeliningClientExchangeHandler.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/reactor/ssl/SSLIOSession.java b/httpcore-nio/src/main/java/org/apache/http/nio/reactor/ssl/SSLIOSession.java
index 297989b..8342bed 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/reactor/ssl/SSLIOSession.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/reactor/ssl/SSLIOSession.java
@@ -65,8 +65,8 @@ import org.apache.http.util.Asserts;
  *  SSLContext sslContext = SSLContext.getInstance("SSL");
  *  sslContext.init(null, null, null);
  *  SSLIOSession sslsession = new SSLIOSession(
- *      iosession, SSLMode.CLIENT, sslContext, null);
- *  iosession.setAttribute(SSLIOSession.SESSION_KEY, sslsession);
+ *      ioSession, SSLMode.CLIENT, sslContext, null);
+ *  ioSession.setAttribute(SSLIOSession.SESSION_KEY, sslsession);
  * </pre>
  *
  * @since 4.2
@@ -591,13 +591,8 @@ public class SSLIOSession implements IOSession, SessionBufferStatus, SocketAcces
                 this.inPlain.release();
             }
             return n;
-        } else {
-            if (this.endOfStream) {
-                return -1;
-            } else {
-                return 0;
-            }
         }
+        return this.endOfStream ? -1 : 0;
     }
 
     @Override
@@ -772,11 +767,7 @@ public class SSLIOSession implements IOSession, SessionBufferStatus, SocketAcces
 
     @Override
     public Socket getSocket(){
-        if (this.session instanceof SocketAccessor){
-            return ((SocketAccessor) this.session).getSocket();
-        } else {
-            return null;
-        }
+        return this.session instanceof SocketAccessor ? ((SocketAccessor) this.session).getSocket() : null;
     }
 
     private class InternalByteChannel implements ByteChannel {

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedInputBuffer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedInputBuffer.java b/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedInputBuffer.java
index 72aa021..9b82739 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedInputBuffer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedInputBuffer.java
@@ -58,7 +58,7 @@ public class SharedInputBuffer extends ExpandableBuffer implements ContentInputB
     private final ReentrantLock lock;
     private final Condition condition;
 
-    private volatile IOControl ioctrl;
+    private volatile IOControl ioControl;
     private volatile boolean shutdown = false;
     private volatile boolean endOfStream = false;
 
@@ -66,9 +66,9 @@ public class SharedInputBuffer extends ExpandableBuffer implements ContentInputB
      * @deprecated (4.3) use {@link SharedInputBuffer#SharedInputBuffer(int, ByteBufferAllocator)}
      */
     @Deprecated
-    public SharedInputBuffer(final int bufferSize, final IOControl ioctrl, final ByteBufferAllocator allocator) {
+    public SharedInputBuffer(final int bufferSize, final IOControl ioControl, final ByteBufferAllocator allocator) {
         super(bufferSize, allocator);
-        this.ioctrl = ioctrl;
+        this.ioControl = ioControl;
         this.lock = new ReentrantLock();
         this.condition = this.lock.newCondition();
     }
@@ -115,14 +115,14 @@ public class SharedInputBuffer extends ExpandableBuffer implements ContentInputB
     /**
      * @since 4.3
      */
-    public int consumeContent(final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+    public int consumeContent(final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         if (this.shutdown) {
             return -1;
         }
         this.lock.lock();
         try {
-            if (ioctrl != null) {
-                this.ioctrl = ioctrl;
+            if (ioControl != null) {
+                this.ioControl = ioControl;
             }
             setInputMode();
             int totalRead = 0;
@@ -134,8 +134,8 @@ public class SharedInputBuffer extends ExpandableBuffer implements ContentInputB
                 this.endOfStream = true;
             }
             if (!this.buffer.hasRemaining()) {
-                if (this.ioctrl != null) {
-                    this.ioctrl.suspendInput();
+                if (this.ioControl != null) {
+                    this.ioControl.suspendInput();
                 }
             }
             this.condition.signalAll();
@@ -197,8 +197,8 @@ public class SharedInputBuffer extends ExpandableBuffer implements ContentInputB
                     if (this.shutdown) {
                         throw new InterruptedIOException("Input operation aborted");
                     }
-                    if (this.ioctrl != null) {
-                        this.ioctrl.requestInput();
+                    if (this.ioControl != null) {
+                        this.ioControl.requestInput();
                     }
                     this.condition.await();
                 }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedOutputBuffer.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedOutputBuffer.java b/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedOutputBuffer.java
index 98b8a75..ef1df00 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedOutputBuffer.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/util/SharedOutputBuffer.java
@@ -60,7 +60,7 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
     private final ReentrantLock lock;
     private final Condition condition;
 
-    private volatile IOControl ioctrl;
+    private volatile IOControl ioControl;
     private volatile boolean shutdown = false;
     private volatile boolean endOfStream = false;
 
@@ -68,10 +68,10 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
      * @deprecated (4.3) use {@link SharedOutputBuffer#SharedOutputBuffer(int, ByteBufferAllocator)}
      */
     @Deprecated
-    public SharedOutputBuffer(final int bufferSize, final IOControl ioctrl, final ByteBufferAllocator allocator) {
+    public SharedOutputBuffer(final int bufferSize, final IOControl ioControl, final ByteBufferAllocator allocator) {
         super(bufferSize, allocator);
-        Args.notNull(ioctrl, "I/O content control");
-        this.ioctrl = ioctrl;
+        Args.notNull(ioControl, "I/O content control");
+        this.ioControl = ioControl;
         this.lock = new ReentrantLock();
         this.condition = this.lock.newCondition();
     }
@@ -158,14 +158,14 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
     /**
      * @since 4.3
      */
-    public int produceContent(final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+    public int produceContent(final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         if (this.shutdown) {
             return -1;
         }
         this.lock.lock();
         try {
-            if (ioctrl != null) {
-                this.ioctrl = ioctrl;
+            if (ioControl != null) {
+                this.ioControl = ioControl;
             }
             setOutputMode();
             int bytesWritten = 0;
@@ -183,8 +183,8 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
                 }
                 if (!this.endOfStream) {
                     // suspend output events
-                    if (this.ioctrl != null) {
-                        this.ioctrl.suspendOutput();
+                    if (this.ioControl != null) {
+                        this.ioControl.suspendOutput();
                     }
                 }
             }
@@ -274,8 +274,8 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
                     if (this.shutdown) {
                         throw new InterruptedIOException("Output operation aborted");
                     }
-                    if (this.ioctrl != null) {
-                        this.ioctrl.requestOutput();
+                    if (this.ioControl != null) {
+                        this.ioControl.requestOutput();
                     }
                     this.condition.await();
                 }
@@ -295,8 +295,8 @@ public class SharedOutputBuffer extends ExpandableBuffer implements ContentOutpu
                 return;
             }
             this.endOfStream = true;
-            if (this.ioctrl != null) {
-                this.ioctrl.requestOutput();
+            if (this.ioControl != null) {
+                this.ioControl.requestOutput();
             }
         } finally {
             this.lock.unlock();

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpClientConnection.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpClientConnection.java b/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpClientConnection.java
index 3cb35d2..f404bfb 100644
--- a/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpClientConnection.java
+++ b/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpClientConnection.java
@@ -159,9 +159,9 @@ public class TestDefaultNHttpClientConnection {
         @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
-            final IOControl ioctrl = (IOControl) args[0];
+            final IOControl ioControl = (IOControl) args[0];
             final ContentEncoder encoder = (ContentEncoder) args[1];
-            contentProducer.produceContent(encoder, ioctrl);
+            contentProducer.produceContent(encoder, ioControl);
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpServerConnection.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpServerConnection.java b/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpServerConnection.java
index 7887683..334c941 100644
--- a/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpServerConnection.java
+++ b/httpcore-nio/src/test/java/org/apache/http/impl/nio/TestDefaultNHttpServerConnection.java
@@ -159,9 +159,9 @@ public class TestDefaultNHttpServerConnection {
         @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
-            final IOControl ioctrl = (IOControl) args[0];
+            final IOControl ioControl = (IOControl) args[0];
             final ContentEncoder encoder = (ContentEncoder) args[1];
-            contentProducer.produceContent(encoder, ioctrl);
+            contentProducer.produceContent(encoder, ioControl);
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/impl/nio/pool/TestBasicNIOConnPool.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/impl/nio/pool/TestBasicNIOConnPool.java b/httpcore-nio/src/test/java/org/apache/http/impl/nio/pool/TestBasicNIOConnPool.java
index 78f9cdc..25e2781 100644
--- a/httpcore-nio/src/test/java/org/apache/http/impl/nio/pool/TestBasicNIOConnPool.java
+++ b/httpcore-nio/src/test/java/org/apache/http/impl/nio/pool/TestBasicNIOConnPool.java
@@ -52,16 +52,16 @@ public class TestBasicNIOConnPool {
     static class LocalPool extends BasicNIOConnPool {
 
         public LocalPool(
-                final ConnectingIOReactor ioreactor,
+                final ConnectingIOReactor ioReactor,
                 final NIOConnFactory<HttpHost, NHttpClientConnection> connFactory,
                 final int connectTimeout) {
-            super(ioreactor, connFactory, connectTimeout);
+            super(ioReactor, connFactory, connectTimeout);
         }
 
         public LocalPool(
-                final ConnectingIOReactor ioreactor,
+                final ConnectingIOReactor ioReactor,
                 final ConnectionConfig config) {
-            super(ioreactor, config);
+            super(ioReactor, config);
         }
 
         @Override

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/impl/nio/reactor/TestDefaultListeningIOReactor.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/impl/nio/reactor/TestDefaultListeningIOReactor.java b/httpcore-nio/src/test/java/org/apache/http/impl/nio/reactor/TestDefaultListeningIOReactor.java
index fab6a58..784b423 100644
--- a/httpcore-nio/src/test/java/org/apache/http/impl/nio/reactor/TestDefaultListeningIOReactor.java
+++ b/httpcore-nio/src/test/java/org/apache/http/impl/nio/reactor/TestDefaultListeningIOReactor.java
@@ -74,14 +74,14 @@ public class TestDefaultListeningIOReactor {
     public void testEndpointUpAndDown() throws Exception {
         final IOEventDispatch eventDispatch = createIOEventDispatch();
         final IOReactorConfig config = IOReactorConfig.custom().setIoThreadCount(1).build();
-        final ListeningIOReactor ioreactor = new DefaultListeningIOReactor(config);
+        final ListeningIOReactor ioReactor = new DefaultListeningIOReactor(config);
 
         final Thread t = new Thread(new Runnable() {
 
             @Override
             public void run() {
                 try {
-                    ioreactor.execute(eventDispatch);
+                    ioReactor.execute(eventDispatch);
                 } catch (final IOException ex) {
                 }
             }
@@ -90,24 +90,24 @@ public class TestDefaultListeningIOReactor {
 
         t.start();
 
-        Set<ListenerEndpoint> endpoints = ioreactor.getEndpoints();
+        Set<ListenerEndpoint> endpoints = ioReactor.getEndpoints();
         Assert.assertNotNull(endpoints);
         Assert.assertEquals(0, endpoints.size());
 
-        final ListenerEndpoint endpoint1 = ioreactor.listen(new InetSocketAddress(0));
+        final ListenerEndpoint endpoint1 = ioReactor.listen(new InetSocketAddress(0));
         endpoint1.waitFor();
 
-        final ListenerEndpoint endpoint2 = ioreactor.listen(new InetSocketAddress(0));
+        final ListenerEndpoint endpoint2 = ioReactor.listen(new InetSocketAddress(0));
         endpoint2.waitFor();
         final int port = ((InetSocketAddress) endpoint2.getAddress()).getPort();
 
-        endpoints = ioreactor.getEndpoints();
+        endpoints = ioReactor.getEndpoints();
         Assert.assertNotNull(endpoints);
         Assert.assertEquals(2, endpoints.size());
 
         endpoint1.close();
 
-        endpoints = ioreactor.getEndpoints();
+        endpoints = ioReactor.getEndpoints();
         Assert.assertNotNull(endpoints);
         Assert.assertEquals(1, endpoints.size());
 
@@ -115,17 +115,17 @@ public class TestDefaultListeningIOReactor {
 
         Assert.assertEquals(port, ((InetSocketAddress) endpoint.getAddress()).getPort());
 
-        ioreactor.shutdown(1000);
+        ioReactor.shutdown(1000);
         t.join(1000);
 
-        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioreactor.getStatus());
+        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioReactor.getStatus());
     }
 
     @Test
     public void testEndpointAlreadyBoundFatal() throws Exception {
         final IOEventDispatch eventDispatch = createIOEventDispatch();
         final IOReactorConfig config = IOReactorConfig.custom().setIoThreadCount(1).build();
-        final ListeningIOReactor ioreactor = new DefaultListeningIOReactor(config);
+        final ListeningIOReactor ioReactor = new DefaultListeningIOReactor(config);
 
         final CountDownLatch latch = new CountDownLatch(1);
 
@@ -134,7 +134,7 @@ public class TestDefaultListeningIOReactor {
             @Override
             public void run() {
                 try {
-                    ioreactor.execute(eventDispatch);
+                    ioReactor.execute(eventDispatch);
                     Assert.fail("IOException should have been thrown");
                 } catch (final IOException ex) {
                     latch.countDown();
@@ -145,35 +145,35 @@ public class TestDefaultListeningIOReactor {
 
         t.start();
 
-        final ListenerEndpoint endpoint1 = ioreactor.listen(new InetSocketAddress(0));
+        final ListenerEndpoint endpoint1 = ioReactor.listen(new InetSocketAddress(0));
         endpoint1.waitFor();
         final int port = ((InetSocketAddress) endpoint1.getAddress()).getPort();
 
-        final ListenerEndpoint endpoint2 = ioreactor.listen(new InetSocketAddress(port));
+        final ListenerEndpoint endpoint2 = ioReactor.listen(new InetSocketAddress(port));
         endpoint2.waitFor();
         Assert.assertNotNull(endpoint2.getException());
 
         // I/O reactor is now expected to be shutting down
         latch.await(2000, TimeUnit.MILLISECONDS);
-        Assert.assertTrue(ioreactor.getStatus().compareTo(IOReactorStatus.SHUTTING_DOWN) >= 0);
+        Assert.assertTrue(ioReactor.getStatus().compareTo(IOReactorStatus.SHUTTING_DOWN) >= 0);
 
-        final Set<ListenerEndpoint> endpoints = ioreactor.getEndpoints();
+        final Set<ListenerEndpoint> endpoints = ioReactor.getEndpoints();
         Assert.assertNotNull(endpoints);
         Assert.assertEquals(0, endpoints.size());
 
-        ioreactor.shutdown(1000);
+        ioReactor.shutdown(1000);
         t.join(1000);
 
-        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioreactor.getStatus());
+        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioReactor.getStatus());
     }
 
     @Test
     public void testEndpointAlreadyBoundNonFatal() throws Exception {
         final IOEventDispatch eventDispatch = createIOEventDispatch();
         final IOReactorConfig config = IOReactorConfig.custom().setIoThreadCount(1).build();
-        final DefaultListeningIOReactor ioreactor = new DefaultListeningIOReactor(config);
+        final DefaultListeningIOReactor ioReactor = new DefaultListeningIOReactor(config);
 
-        ioreactor.setExceptionHandler(new IOReactorExceptionHandler() {
+        ioReactor.setExceptionHandler(new IOReactorExceptionHandler() {
 
             @Override
             public boolean handle(final IOException ex) {
@@ -192,7 +192,7 @@ public class TestDefaultListeningIOReactor {
             @Override
             public void run() {
                 try {
-                    ioreactor.execute(eventDispatch);
+                    ioReactor.execute(eventDispatch);
                 } catch (final IOException ex) {
                 }
             }
@@ -201,22 +201,22 @@ public class TestDefaultListeningIOReactor {
 
         t.start();
 
-        final ListenerEndpoint endpoint1 = ioreactor.listen(new InetSocketAddress(9999));
+        final ListenerEndpoint endpoint1 = ioReactor.listen(new InetSocketAddress(9999));
         endpoint1.waitFor();
 
-        final ListenerEndpoint endpoint2 = ioreactor.listen(new InetSocketAddress(9999));
+        final ListenerEndpoint endpoint2 = ioReactor.listen(new InetSocketAddress(9999));
         endpoint2.waitFor();
         Assert.assertNotNull(endpoint2.getException());
 
         // Sleep a little to make sure the I/O reactor is not shutting down
         Thread.sleep(500);
 
-        Assert.assertEquals(IOReactorStatus.ACTIVE, ioreactor.getStatus());
+        Assert.assertEquals(IOReactorStatus.ACTIVE, ioReactor.getStatus());
 
-        ioreactor.shutdown(1000);
+        ioReactor.shutdown(1000);
         t.join(1000);
 
-        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioreactor.getStatus());
+        Assert.assertEquals(IOReactorStatus.SHUT_DOWN, ioReactor.getStatus());
     }
 
 }

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestCustomSSL.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestCustomSSL.java b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestCustomSSL.java
index 435c0c8..f3f96f3 100644
--- a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestCustomSSL.java
+++ b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestCustomSSL.java
@@ -93,9 +93,9 @@ public class TestCustomSSL {
 
             @Override
             public void verify(
-                    final IOSession iosession, final SSLSession sslsession) throws SSLException {
+                    final IOSession ioSession, final SSLSession sslsession) throws SSLException {
                 final BigInteger sslid = new BigInteger(sslsession.getId());
-                iosession.setAttribute("ssl-id", sslid);
+                ioSession.setAttribute("ssl-id", sslid);
             }
 
         };

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlerCancellable.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlerCancellable.java b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlerCancellable.java
index 2524888..48cc77f 100644
--- a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlerCancellable.java
+++ b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlerCancellable.java
@@ -98,9 +98,9 @@ public class TestHttpAsyncHandlerCancellable extends HttpCoreNIOTestBase {
 
             @Override
             public void produceContent(
-                    final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+                    final ContentEncoder encoder, final IOControl ioControl) throws IOException {
                 // suspend output
-                ioctrl.suspendOutput();
+                ioControl.suspendOutput();
             }
 
             @Override

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncPrematureTermination.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncPrematureTermination.java b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncPrematureTermination.java
index a99a920..8601682 100644
--- a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncPrematureTermination.java
+++ b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncPrematureTermination.java
@@ -230,8 +230,8 @@ public class TestHttpAsyncPrematureTermination extends HttpCoreNIOTestBase {
                     @Override
                     public synchronized void produceContent(
                             final ContentEncoder encoder,
-                            final IOControl ioctrl) throws IOException {
-                        ioctrl.shutdown();
+                            final IOControl ioControl) throws IOException {
+                        ioControl.shutdown();
                     }
 
                 });

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestTruncatedChunks.java
----------------------------------------------------------------------
diff --git a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestTruncatedChunks.java b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestTruncatedChunks.java
index 8f4c648..797a6a5 100644
--- a/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestTruncatedChunks.java
+++ b/httpcore-nio/src/test/java/org/apache/http/nio/integration/TestTruncatedChunks.java
@@ -211,7 +211,7 @@ public class TestTruncatedChunks extends HttpCoreNIOTestBase {
 
         @Override
         protected void onContentReceived(
-                final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+                final ContentDecoder decoder, final IOControl ioControl) throws IOException {
             boolean finished = false;
             try {
                 this.buffer.consumeContent(decoder);
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncClientExchangeHandler.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncClientExchangeHandler.java
index eb3eabe..a1b63d1 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncClientExchangeHandler.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncClientExchangeHandler.java
@@ -62,7 +62,7 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
     private final BasicFuture<T> future;
     private final HttpContext localContext;
     private final NHttpClientConnection conn;
-    private final HttpProcessor httppocessor;
+    private final HttpProcessor httpPocessor;
     private final ConnectionReuseStrategy connReuseStrategy;
     private final AtomicBoolean requestSent;
     private final AtomicBoolean keepAlive;
@@ -76,7 +76,7 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param callback the future callback invoked when the operation is completed.
      * @param localContext the local execution context.
      * @param conn the actual connection.
      * @param httppocessor the HTTP protocol processor.
      * @param connReuseStrategy the connection re-use strategy.
      */
     public BasicAsyncClientExchangeHandler(
@@ -85,7 +85,7 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
             final FutureCallback<T> callback,
             final HttpContext localContext,
             final NHttpClientConnection conn,
-            final HttpProcessor httppocessor,
+            final HttpProcessor httpPocessor,
             final ConnectionReuseStrategy connReuseStrategy) {
         super();
         this.requestProducer = Args.notNull(requestProducer, "Request producer");
@@ -93,7 +93,7 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
         this.future = new BasicFuture<T>(callback);
         this.localContext = Args.notNull(localContext, "HTTP context");
         this.conn = Args.notNull(conn, "HTTP connection");
-        this.httppocessor = Args.notNull(httppocessor, "HTTP processor");
+        this.httpPocessor = Args.notNull(httpPocessor, "HTTP processor");
         this.connReuseStrategy = connReuseStrategy != null ? connReuseStrategy :
             DefaultConnectionReuseStrategy.INSTANCE;
         this.requestSent = new AtomicBoolean(false);
@@ -108,15 +108,15 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param responseConsumer the response consumer.
      * @param localContext the local execution context.
      * @param conn the actual connection.
      * @param httppocessor the HTTP protocol processor.
      */
     public BasicAsyncClientExchangeHandler(
             final HttpAsyncRequestProducer requestProducer,
             final HttpAsyncResponseConsumer<T> responseConsumer,
             final HttpContext localContext,
             final NHttpClientConnection conn,
-            final HttpProcessor httppocessor) {
-        this(requestProducer, responseConsumer, null, localContext, conn, httppocessor, null);
+            final HttpProcessor httpPocessor) {
+        this(requestProducer, responseConsumer, null, localContext, conn, httpPocessor, null);
     }
 
     public Future<T> getFuture() {
@@ -152,14 +152,14 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
         final HttpRequest request = this.requestProducer.generateRequest();
         this.localContext.setAttribute(HttpCoreContext.HTTP_REQUEST, request);
         this.localContext.setAttribute(HttpCoreContext.HTTP_CONNECTION, this.conn);
-        this.httppocessor.process(request, this.localContext);
+        this.httpPocessor.process(request, this.localContext);
         return request;
     }
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
-        this.requestProducer.produceContent(encoder, ioctrl);
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
+        this.requestProducer.produceContent(encoder, ioControl);
     }
 
     @Override
@@ -171,15 +171,15 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
     @Override
     public void responseReceived(final HttpResponse response) throws IOException, HttpException {
         this.localContext.setAttribute(HttpCoreContext.HTTP_RESPONSE, response);
-        this.httppocessor.process(response, this.localContext);
+        this.httpPocessor.process(response, this.localContext);
         this.responseConsumer.responseReceived(response);
         this.keepAlive.set(this.connReuseStrategy.keepAlive(response, this.localContext));
     }
 
     @Override
     public void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
-        this.responseConsumer.consumeContent(decoder, ioctrl);
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
+        this.responseConsumer.consumeContent(decoder, ioControl);
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/protocol/BasicAsyncRequestConsumer.java
----------------------------------------------------------------------
@@ -76,7 +76,7 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param localContext the local execution context.
      * @param conn the actual connection.
-     * @param httppocessor the HTTP protocol processor.
+     * @param httpPocessor the HTTP protocol processor.
      * @param connReuseStrategy the connection re-use strategy.
      */
@@ -108,15 +108,15 @@ public class BasicAsyncClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param localContext the local execution context.
      * @param conn the actual connection.
-     * @param httppocessor the HTTP protocol processor.
+     * @param httpPocessor the HTTP protocol processor.
      */
     public BasicAsyncClientExchangeHandler(
diff --git a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/PipeliningClientExchangeHandler.java b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/PipeliningClientExchangeHandler.java
index 5c21768..50d1886 100644
--- a/httpcore-nio/src/main/java/org/apache/http/nio/protocol/PipeliningClientExchangeHandler.java
+++ b/httpcore-nio/src/main/java/org/apache/http/nio/protocol/PipeliningClientExchangeHandler.java
@@ -72,7 +72,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
     private final BasicFuture<List<T>> future;
     private final HttpContext localContext;
     private final NHttpClientConnection conn;
-    private final HttpProcessor httppocessor;
+    private final HttpProcessor httpPocessor;
     private final ConnectionReuseStrategy connReuseStrategy;
 
     private final AtomicReference<HttpAsyncRequestProducer> requestProducerRef;
@@ -88,7 +88,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param callback the future callback invoked when the operation is completed.
      * @param localContext the local execution context.
      * @param conn the actual connection.
      * @param httppocessor the HTTP protocol processor.
      * @param connReuseStrategy the connection re-use strategy.
      */
     public PipeliningClientExchangeHandler(
@@ -97,7 +97,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
             final FutureCallback<List<T>> callback,
             final HttpContext localContext,
             final NHttpClientConnection conn,
-            final HttpProcessor httppocessor,
+            final HttpProcessor httpPocessor,
             final ConnectionReuseStrategy connReuseStrategy) {
         super();
         Args.notEmpty(requestProducers, "Request producer list");
@@ -111,7 +111,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
         this.future = new BasicFuture<List<T>>(callback);
         this.localContext = Args.notNull(localContext, "HTTP context");
         this.conn = Args.notNull(conn, "HTTP connection");
-        this.httppocessor = Args.notNull(httppocessor, "HTTP processor");
+        this.httpPocessor = Args.notNull(httpPocessor, "HTTP processor");
         this.connReuseStrategy = connReuseStrategy != null ? connReuseStrategy :
             DefaultConnectionReuseStrategy.INSTANCE;
         this.localContext.setAttribute(HttpCoreContext.HTTP_CONNECTION, this.conn);
@@ -128,15 +128,15 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param responseConsumers the response consumers.
      * @param localContext the local execution context.
      * @param conn the actual connection.
      * @param httppocessor the HTTP protocol processor.
      */
     public PipeliningClientExchangeHandler(
             final List<? extends HttpAsyncRequestProducer> requestProducers,
             final List<? extends HttpAsyncResponseConsumer<T>> responseConsumers,
             final HttpContext localContext,
             final NHttpClientConnection conn,
-            final HttpProcessor httppocessor) {
-        this(requestProducers, responseConsumers, null, localContext, conn, httppocessor, null);
+            final HttpProcessor httpPocessor) {
+        this(requestProducers, responseConsumers, null, localContext, conn, httpPocessor, null);
     }
 
     public Future<List<T>> getFuture() {
@@ -184,17 +184,17 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
         }
         this.requestProducerRef.set(requestProducer);
         final HttpRequest request = requestProducer.generateRequest();
-        this.httppocessor.process(request, this.localContext);
+        this.httpPocessor.process(request, this.localContext);
         this.requestQueue.add(request);
         return request;
     }
 
     @Override
     public void produceContent(
-            final ContentEncoder encoder, final IOControl ioctrl) throws IOException {
+            final ContentEncoder encoder, final IOControl ioControl) throws IOException {
         final HttpAsyncRequestProducer requestProducer = this.requestProducerRef.get();
         Asserts.check(requestProducer != null, "Inconsistent state: request producer is null");
-        requestProducer.produceContent(encoder, ioctrl);
+        requestProducer.produceContent(encoder, ioControl);
     }
 
     @Override
@@ -217,7 +217,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
 
         this.localContext.setAttribute(HttpCoreContext.HTTP_REQUEST, request);
         this.localContext.setAttribute(HttpCoreContext.HTTP_RESPONSE, response);
-        this.httppocessor.process(response, this.localContext);
+        this.httpPocessor.process(response, this.localContext);
 
         responseConsumer.responseReceived(response);
         this.keepAlive.set(this.connReuseStrategy.keepAlive(response, this.localContext));
@@ -225,10 +225,10 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
 
     @Override
     public void consumeContent(
-            final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
+            final ContentDecoder decoder, final IOControl ioControl) throws IOException {
         final HttpAsyncResponseConsumer<T> responseConsumer = this.responseConsumerRef.get();
         Asserts.check(responseConsumer != null, "Inconsistent state: response consumer is null");
-        responseConsumer.consumeContent(decoder, ioctrl);
+        responseConsumer.consumeContent(decoder, ioControl);
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/07a4acf7/httpcore-nio/src/main/java/org/apache/http/nio/reactor/ssl/SSLIOSession.java
----------------------------------------------------------------------
@@ -88,7 +88,7 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param localContext the local execution context.
      * @param conn the actual connection.
-     * @param httppocessor the HTTP protocol processor.
+     * @param httpPocessor the HTTP protocol processor.
      * @param connReuseStrategy the connection re-use strategy.
      */
@@ -128,15 +128,15 @@ public class PipeliningClientExchangeHandler<T> implements HttpAsyncClientExchan
      * @param localContext the local execution context.
      * @param conn the actual connection.
-     * @param httppocessor the HTTP protocol processor.
+     * @param httpPocessor the HTTP protocol processor.
      */
     public PipeliningClientExchangeHandler(